

/*  The cache database file on disc consists of interspersed
    dbCacheHeader structure in native desktop format and byte
    streams of the actual packed database records from the
    handheld.  When adding items to the cache we break out
    fields from the database record which permit it to be
    identified in the cache without the need to unpack it.
    This allows quickly skipping invariant and irrelevant
    records when scanning the cache.  */

struct dbCacheHeader {
    short year;                       /* Year (ex. 1999, 2071) */
    short month;                      /* Month (0 - 11) */
    time_t modtime;                   /* Unix time/date of last
                                         modification (update in the
                                         desktop cache, not on the handheld) */
    short flags;                      /* Record flags, to wit: */
#define dbchDirty   1                 /* Record modified since load */
    short rbytes;                     /* Number of bytes in database record */
/*  unsigned char dbrec[rbytes];         Actual database record */
};

struct dbMemCacheHeader {
    struct dbCacheHeader h;
    unsigned char dbrec[2];           /* Actual database record */
};

extern struct dbMemCacheHeader **cacheT;  /* Cache pointer table */

extern struct dbMemCacheHeader *findInCache(int year, int month);
extern void dbCacheOpen(FILE *fp);
extern void dbCacheEmpty(void);
extern void dbCachePrint(FILE *fo);
extern int dbCacheAdd(int year, int month, unsigned char *rec, int recl);
extern int dbIsCacheDirty(void);
extern void dbCacheWrite(FILE *fp);
