/*
    
                    The Hacker's Diet

                    Unit Conversions
                     
*/

#include "database.h"
#include "units.h"

static double weightConversion[3][3] =
{
/*  To:     kg              lb          st         */
/*  From                                           */
/* kg */  { 1.0,        2.2046226,  0.15747304  },
/* lb */  { 0.45359237, 1.0,        0.07142857  },
/* st */  { 6.35029324, 14.0,       1.0         }
};          

/*  convertWeight  --  Convert a weight from one unit system to
                       another, if necessary.  */

weight convertWeight(weight w, weightunit from, weightunit to)
{
    if (from != to) {
        w = (weight) ((((double) w) * weightConversion[from][to]) + 0.5);
    }
    
    return w;
}

/*  convertTrend  --  Convert a trend value from one unit system to
                      another, if necessary.  */
                      
trend convertTrend(trend t, weightunit from, weightunit to)
{
    if (from != to) {
        t = (trend) ((((double) t) * weightConversion[from][to]) + 0.5);
    }
    
    return t;
}


/*  convertLong  --  Convert a signed long value between units if necessary.  */

signed long convertLong(signed long l, weightunit from, weightunit to)
{
    if (from != to) {
        l = (signed long) ((((double) l) * weightConversion[from][to]) + 0.5);
    }
    
    return l;
}
